@@ -17,11 +17,19 @@ impl<'a> Context<'a> {
         int: &impl fend_core::Interrupt,
     ) -> Result<fend_core::FendResult, String> {
         if keep_results {
-            let mut c = self.ctx.borrow_mut();
-            fend_core::evaluate_with_interrupt(line, &mut c, int)
+            let mut ctx_borrow = self.ctx.borrow_mut();
+            ctx_borrow.set_random_u32_fn(random_u32);
+            ctx_borrow.set_output_mode_terminal();
+            fend_core::evaluate_with_interrupt(line, &mut ctx_borrow, int)
         } else {
             let mut ctx_clone = self.ctx.borrow().clone();
+            ctx_clone.disable_rng();
+            ctx_clone.set_output_mode_terminal();
             fend_core::evaluate_with_interrupt(line, &mut ctx_clone, int)
         }
     }
 }
+
+fn random_u32() -> u32 {
+    rand::random()
+}
